==> cscec5b-wzxt-impl-3.0.0-20210318.082941-153-sources.jar: com/ejianc/business/wzxt/bean/ExitApplyDetailEntity.java <==
package com.ejianc.business.wzxt.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 退场申请单明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_wzxt_exit_apply_detail")
public class ExitApplyDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="p_id")
    private java.lang.Long pId; // 退场申请单ID
    @TableField(value="refer_type")
    private java.lang.Integer referType; // 参照类型(1在场周转材2材料库)
    @TableField(value="material_id")
    private java.lang.Long materialId; // 物资主键
    @TableField(value="material_source_id")
    private java.lang.String materialSourceId; // 物资来源主键
    @TableField(value="material_type_id")
    private java.lang.Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private java.lang.String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private java.lang.String materialCode; // 物料编码
    @TableField(value="material_name")
    private java.lang.String materialName; // 物资名称
    @TableField(value="spec")
    private java.lang.String spec; // 型号
    @TableField(value="measure_unit")
    private java.lang.String measureUnit; // 计量单位
    @TableField(value="on_rent_num")
    private java.math.BigDecimal onRentNum; // 在租数量
    @TableField(value="apply_exit_num")
    private java.math.BigDecimal applyExitNum; // 申请退场数量
    @TableField(value="exited_num")
    private java.math.BigDecimal exitedNum; // 已退场数量
    @TableField(value="off_rent_date")
    private java.util.Date offRentDate; // 止租日
    @TableField(value="memo")
    private java.lang.String memo; // 备注
    @TableField(value="def1")
    private java.lang.String def1; // 
    @TableField(value="def2")
    private java.lang.String def2; // 
    @TableField(value="def3")
    private java.lang.String def3; // 
    @TableField(value="def4")
    private java.lang.String def4; // 
    @TableField(value="def5")
    private java.lang.String def5; // 
    
    
    

    /**
     * 退场申请单ID
     */
    public java.lang.Long getPId() {
        return pId;
    }

    /**
     * 退场申请单ID
     */
    public void setPId(java.lang.Long pId) {
        this.pId = pId;
    }
    /**
     * 参照类型(1在场周转材2材料库)
     */
    public java.lang.Integer getReferType() {
        return referType;
    }

    /**
     * 参照类型(1在场周转材2材料库)
     */
    public void setReferType(java.lang.Integer referType) {
        this.referType = referType;
    }
    /**
     * 物资主键
     */
    public java.lang.Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(java.lang.Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资来源主键
     */
    public java.lang.String getMaterialSourceId() {
        return materialSourceId;
    }

    /**
     * 物资来源主键
     */
    public void setMaterialSourceId(java.lang.String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    /**
     * 物资类别
     */
    public java.lang.Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(java.lang.Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public java.lang.String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(java.lang.String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public java.lang.String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(java.lang.String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 计量单位
     */
    public java.lang.String getMeasureUnit() {
        return measureUnit;
    }

    /**
     * 计量单位
     */
    public void setMeasureUnit(java.lang.String measureUnit) {
        this.measureUnit = measureUnit;
    }
    /**
     * 在租数量
     */
    public java.math.BigDecimal getOnRentNum() {
        return onRentNum;
    }

    /**
     * 在租数量
     */
    public void setOnRentNum(java.math.BigDecimal onRentNum) {
        this.onRentNum = onRentNum;
    }
    /**
     * 申请退场数量
     */
    public java.math.BigDecimal getApplyExitNum() {
        return applyExitNum;
    }

    /**
     * 申请退场数量
     */
    public void setApplyExitNum(java.math.BigDecimal applyExitNum) {
        this.applyExitNum = applyExitNum;
    }
    /**
     * 已退场数量
     */
    public java.math.BigDecimal getExitedNum() {
        return exitedNum;
    }

    /**
     * 已退场数量
     */
    public void setExitedNum(java.math.BigDecimal exitedNum) {
        this.exitedNum = exitedNum;
    }
    /**
     * 止租日
     */
    public java.util.Date getOffRentDate() {
        return offRentDate;
    }

    /**
     * 止租日
     */
    public void setOffRentDate(java.util.Date offRentDate) {
        this.offRentDate = offRentDate;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 
     */
    public java.lang.String getDef1() {
        return def1;
    }

    /**
     * 
     */
    public void setDef1(java.lang.String def1) {
        this.def1 = def1;
    }
    /**
     * 
     */
    public java.lang.String getDef2() {
        return def2;
    }

    /**
     * 
     */
    public void setDef2(java.lang.String def2) {
        this.def2 = def2;
    }
    /**
     * 
     */
    public java.lang.String getDef3() {
        return def3;
    }

    /**
     * 
     */
    public void setDef3(java.lang.String def3) {
        this.def3 = def3;
    }
    /**
     * 
     */
    public java.lang.String getDef4() {
        return def4;
    }

    /**
     * 
     */
    public void setDef4(java.lang.String def4) {
        this.def4 = def4;
    }
    /**
     * 
     */
    public java.lang.String getDef5() {
        return def5;
    }

    /**
     * 
     */
    public void setDef5(java.lang.String def5) {
        this.def5 = def5;
    }
    
}

==> cscec5b-wzxt-impl-3.0.0-20210712.110554-269-sources.jar: com/ejianc/business/wzxt/bean/ExitApplyDetailEntity.java <==
package com.ejianc.business.wzxt.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 退场申请单明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_wzxt_exit_apply_detail")
public class ExitApplyDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="p_id")
    private java.lang.Long pId; // 退场申请单ID
    @TableField(value="refer_type")
    private java.lang.Integer referType; // 参照类型(1在场周转材2材料库)
    @TableField(value="material_id")
    private java.lang.Long materialId; // 物资主键
    @TableField(value="material_source_id")
    private java.lang.String materialSourceId; // 物资来源主键
    @TableField(value="material_type_id")
    private java.lang.Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private java.lang.String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private java.lang.String materialCode; // 物料编码
    @TableField(value="material_name")
    private java.lang.String materialName; // 物资名称
    @TableField(value="spec")
    private java.lang.String spec; // 型号
    @TableField(value="unit")
    private java.lang.String unit; // 计量单位
    @TableField(value="on_rent_num")
    private java.math.BigDecimal onRentNum; // 在租数量
    @TableField(value="apply_exit_num")
    private java.math.BigDecimal applyExitNum; // 申请退场数量
    @TableField(value="exited_num")
    private java.math.BigDecimal exitedNum; // 已退场数量
    @TableField(value="off_rent_date")
    private java.util.Date offRentDate; // 止租日
    @TableField(value="memo")
    private java.lang.String memo; // 备注
    @TableField(value="def1")
    private java.lang.String def1; // 
    @TableField(value="def2")
    private java.lang.String def2; // 
    @TableField(value="def3")
    private java.lang.String def3; // 
    @TableField(value="def4")
    private java.lang.String def4; // 
    @TableField(value="def5")
    private java.lang.String def5; // 
    
    
    

    /**
     * 退场申请单ID
     */
    public java.lang.Long getPId() {
        return pId;
    }

    /**
     * 退场申请单ID
     */
    public void setPId(java.lang.Long pId) {
        this.pId = pId;
    }
    /**
     * 参照类型(1在场周转材2材料库)
     */
    public java.lang.Integer getReferType() {
        return referType;
    }

    /**
     * 参照类型(1在场周转材2材料库)
     */
    public void setReferType(java.lang.Integer referType) {
        this.referType = referType;
    }
    /**
     * 物资主键
     */
    public java.lang.Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(java.lang.Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资来源主键
     */
    public java.lang.String getMaterialSourceId() {
        return materialSourceId;
    }

    /**
     * 物资来源主键
     */
    public void setMaterialSourceId(java.lang.String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    /**
     * 物资类别
     */
    public java.lang.Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(java.lang.Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public java.lang.String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(java.lang.String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public java.lang.String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(java.lang.String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    /**
     * 在租数量
     */
    public java.math.BigDecimal getOnRentNum() {
        return onRentNum;
    }

    /**
     * 在租数量
     */
    public void setOnRentNum(java.math.BigDecimal onRentNum) {
        this.onRentNum = onRentNum;
    }
    /**
     * 申请退场数量
     */
    public java.math.BigDecimal getApplyExitNum() {
        return applyExitNum;
    }

    /**
     * 申请退场数量
     */
    public void setApplyExitNum(java.math.BigDecimal applyExitNum) {
        this.applyExitNum = applyExitNum;
    }
    /**
     * 已退场数量
     */
    public java.math.BigDecimal getExitedNum() {
        return exitedNum;
    }

    /**
     * 已退场数量
     */
    public void setExitedNum(java.math.BigDecimal exitedNum) {
        this.exitedNum = exitedNum;
    }
    /**
     * 止租日
     */
    public java.util.Date getOffRentDate() {
        return offRentDate;
    }

    /**
     * 止租日
     */
    public void setOffRentDate(java.util.Date offRentDate) {
        this.offRentDate = offRentDate;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 
     */
    public java.lang.String getDef1() {
        return def1;
    }

    /**
     * 
     */
    public void setDef1(java.lang.String def1) {
        this.def1 = def1;
    }
    /**
     * 
     */
    public java.lang.String getDef2() {
        return def2;
    }

    /**
     * 
     */
    public void setDef2(java.lang.String def2) {
        this.def2 = def2;
    }
    /**
     * 
     */
    public java.lang.String getDef3() {
        return def3;
    }

    /**
     * 
     */
    public void setDef3(java.lang.String def3) {
        this.def3 = def3;
    }
    /**
     * 
     */
    public java.lang.String getDef4() {
        return def4;
    }

    /**
     * 
     */
    public void setDef4(java.lang.String def4) {
        this.def4 = def4;
    }
    /**
     * 
     */
    public java.lang.String getDef5() {
        return def5;
    }

    /**
     * 
     */
    public void setDef5(java.lang.String def5) {
        this.def5 = def5;
    }
    
}
